autowisp.tests.test_measure_aperture_photometry module — AutoWISP documentation

# autowisp.tests.test_measure_aperture_photometry module

## Class Inheritance Diagram

Define test case for the fit_star_shape step.

class autowisp.tests.test_measure_aperture_photometry.TestMeasureAperturePhotometry(methodName='runTest')

  Bases: `H5TestCase`

  Tests of the fit_star_shape step.

  static is_magfit(dr_path)

    Check if the given path within a DR file is related to magfit.

  test_measure_aperture_photometry()

    Run the fit_star_shape step and check the outputs.